==> camel-k-model-v1-6.5.0-sources.jar: io/fabric8/camelk/v1/RepositoryPolicyFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RepositoryPolicyFluentImpl<A extends RepositoryPolicyFluent<A>> extends BaseFluent<A> implements RepositoryPolicyFluent<A>{
  public RepositoryPolicyFluentImpl() {
  }
  public RepositoryPolicyFluentImpl(RepositoryPolicy instance) {
    this.withChecksumPolicy(instance.getChecksumPolicy()); 
    this.withEnabled(instance.getEnabled()); 
    this.withUpdatePolicy(instance.getUpdatePolicy()); 
  }
  private String checksumPolicy;
  private Boolean enabled;
  private String updatePolicy;
  public String getChecksumPolicy() {
    return this.checksumPolicy;
  }
  public A withChecksumPolicy(String checksumPolicy) {
    this.checksumPolicy=checksumPolicy; return (A) this;
  }
  public Boolean hasChecksumPolicy() {
    return this.checksumPolicy != null;
  }
  public Boolean getEnabled() {
    return this.enabled;
  }
  public A withEnabled(Boolean enabled) {
    this.enabled=enabled; return (A) this;
  }
  public Boolean hasEnabled() {
    return this.enabled != null;
  }
  public String getUpdatePolicy() {
    return this.updatePolicy;
  }
  public A withUpdatePolicy(String updatePolicy) {
    this.updatePolicy=updatePolicy; return (A) this;
  }
  public Boolean hasUpdatePolicy() {
    return this.updatePolicy != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RepositoryPolicyFluentImpl that = (RepositoryPolicyFluentImpl) o;
    if (checksumPolicy != null ? !checksumPolicy.equals(that.checksumPolicy) :that.checksumPolicy != null) return false;
    if (enabled != null ? !enabled.equals(that.enabled) :that.enabled != null) return false;
    if (updatePolicy != null ? !updatePolicy.equals(that.updatePolicy) :that.updatePolicy != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(checksumPolicy,  enabled,  updatePolicy,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (checksumPolicy != null) { sb.append("checksumPolicy:"); sb.append(checksumPolicy + ","); }
    if (enabled != null) { sb.append("enabled:"); sb.append(enabled + ","); }
    if (updatePolicy != null) { sb.append("updatePolicy:"); sb.append(updatePolicy); }
    sb.append("}");
    return sb.toString();
  }
  public A withEnabled() {
    return withEnabled(true);
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/RepositoryPolicyFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RepositoryPolicyFluentImpl<A extends RepositoryPolicyFluent<A>> extends BaseFluent<A> implements RepositoryPolicyFluent<A>{
  public RepositoryPolicyFluentImpl() {
  }
  public RepositoryPolicyFluentImpl(RepositoryPolicy instance) {
    if (instance != null) {
      this.withChecksumPolicy(instance.getChecksumPolicy());
      this.withEnabled(instance.getEnabled());
      this.withUpdatePolicy(instance.getUpdatePolicy());
    }
  }
  private String checksumPolicy;
  private Boolean enabled;
  private String updatePolicy;
  public String getChecksumPolicy() {
    return this.checksumPolicy;
  }
  public A withChecksumPolicy(String checksumPolicy) {
    this.checksumPolicy=checksumPolicy; return (A) this;
  }
  public Boolean hasChecksumPolicy() {
    return this.checksumPolicy != null;
  }
  public Boolean getEnabled() {
    return this.enabled;
  }
  public A withEnabled(Boolean enabled) {
    this.enabled=enabled; return (A) this;
  }
  public Boolean hasEnabled() {
    return this.enabled != null;
  }
  public String getUpdatePolicy() {
    return this.updatePolicy;
  }
  public A withUpdatePolicy(String updatePolicy) {
    this.updatePolicy=updatePolicy; return (A) this;
  }
  public Boolean hasUpdatePolicy() {
    return this.updatePolicy != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RepositoryPolicyFluentImpl that = (RepositoryPolicyFluentImpl) o;
    if (!java.util.Objects.equals(checksumPolicy, that.checksumPolicy)) return false;

    if (!java.util.Objects.equals(enabled, that.enabled)) return false;

    if (!java.util.Objects.equals(updatePolicy, that.updatePolicy)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(checksumPolicy,  enabled,  updatePolicy,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (checksumPolicy != null) { sb.append("checksumPolicy:"); sb.append(checksumPolicy + ","); }
    if (enabled != null) { sb.append("enabled:"); sb.append(enabled + ","); }
    if (updatePolicy != null) { sb.append("updatePolicy:"); sb.append(updatePolicy); }
    sb.append("}");
    return sb.toString();
  }
  public A withEnabled() {
    return withEnabled(true);
  }
  
}
